@@ -15,12 +15,17 @@
 
 """Base class(es) for WSGI Middleware."""
 
-from inspect import getargspec
+import six
+
+from oslo_config import cfg
 import webob.dec
 import webob.request
 import webob.response
 
-from oslo_config import cfg
+if six.PY2:
+    from inspect import getargspec as getfullargspec
+else:
+    from inspect import getfullargspec
 
 
 class NoContentTypeResponse(webob.response.Response):
@@ -124,7 +129,7 @@ class ConfigurableMiddleware(object):
             return response
         response = req.get_response(self.application)
 
-        (args, varargs, varkw, defaults) = getargspec(self.process_response)
+        args = getfullargspec(self.process_response)[0]
         if 'request' in args:
             return self.process_response(response, request=req)
         return self.process_response(response)
